clique.var.test(y1,y2,dag,alpha)gRbase for more details.The expression data may contain some genes differing from those in the pathway: in such case the function automatically takes the intersection between the two gene sets.
This function requires gRBase and qpgraph packages.
pathway.var.test, pathway.mean.test,
clique.mean.test,
data(examples)
clique.var.test(y1, y2, dag_bcell, 0.05)
Run the code above in your browser using DataLab