pathway.mean.test(y1,y2,dag,alpha,perm.num=10000,variance=TRUE,paired=FALSE)gRbase for more details.TRUE estimated variances s1 and s2 are reported.TRUE Hotelling test for paired samples is calculated and the test on the variances is not performed.TRUE, this is not returned.TRUE, this is not returned.TRUE, this is not returned.TRUE variances are heteroschedastic. If paired is TRUE, this is not returned.TRUE, this is not returned.TRUE, this is not returned.pathway.var.test.The expression data may contain some genes differing from those in the pathway: in such case the function automatically takes the intersection between the two gene sets.
This function requires gRBase and qpgraph packages.
pathway.var.test, clique.var.test,
clique.mean.test,
data(examples)
pathway.mean.test(y1, y2, dag_bcell, 0.05, 100)
Run the code above in your browser using DataLab